﻿using System;
using TechTalk.SpecFlow;

namespace BTS.Testing.TraceMonitor.BizUnit4.TestSteps.Tests.Steps
{
    [Binding]
    public class StepDefinitions
    {
        private const string TraceQueuePath = @".\private$\BTS.Testing.TraceMonitor";
#if DEBUG
        private const string TraceToolPath = @"..\..\..\BTS.Testing.TraceMonitor\bin\debug\BTS.Testing.TraceMonitor.exe";
#else
        private const string TraceToolPath = @"..\..\..\BTS.Testing.TraceMonitor\bin\release\BTS.Testing.TraceMonitor.exe";
#endif
        [BeforeScenario("StartTraceMonitor")]
        public void SetupTraceMonitor()
        {
            var testCase = new BizUnit.Xaml.TestCase();
            testCase.ExecutionSteps.Add(
                new StartRealtimeEventTrace()
                {
                    TraceToolPath = TraceToolPath
                });
            new BizUnit.BizUnit(testCase).RunTest();
        }
        [AfterScenario("StopTraceMonitor")]
        public void TearDownTraceMonitor()
        {
            var testCase = new BizUnit.Xaml.TestCase();
            testCase.ExecutionSteps.Add(
                new StopRealtimeEventTrace());
                
            new BizUnit.BizUnit(testCase).RunTest();
        }
        [Given(@"A running trace monitor")]
        public void GivenARunningTraceMonitor()
        {
            Console.WriteLine("Assume this is running");
        }

        [Then(@"I can check for the existance of the event by polling all events")]
        public void ThenICanCheckForTheExistanceOfTheEventByPollingAllEvents()
        {
            var testCase = new BizUnit.Xaml.TestCase();
            testCase.ExecutionSteps.Add(
                new PollForEvent()
                {
                    DeleteAfterFound = false,
                    IncludeBodyCompare = true,
                    QueuePath = TraceQueuePath,
                    RegEx = "This is a test cat team event",
                    TimeoutSeconds = 10
                });
            new BizUnit.BizUnit(testCase).RunTest();
        }

        [Then(@"I can check for the existance of the event through the bizunit steps")]
        public void ThenICanCheckForTheExistanceOfTheEventThroughTheBizunitSteps()
        {
            var testCase = new BizUnit.Xaml.TestCase();
            testCase.ExecutionSteps.Add(
                new PollForNextEvent()
                {
                    DeleteAfterFound = false,
                    IncludeBodyCompare = true,
                    QueuePath = TraceQueuePath,
                    RegEx = "This is a test cat team event",
                    TimeoutSeconds = 10
                });
            new BizUnit.BizUnit(testCase).RunTest();
            
        }

        [Then(@"I can delete the event")]
        public void ThenICanDeleteTheEvent()
        {
            var testCase = new BizUnit.Xaml.TestCase();
            testCase.ExecutionSteps.Add(
                new PollForEvent()
                {
                    DeleteAfterFound = true,
                    IncludeBodyCompare = true,
                    QueuePath = TraceQueuePath,
                    RegEx = "This is a test cat team event",
                    TimeoutSeconds = 10
                });
            new BizUnit.BizUnit(testCase).RunTest();
        }

        [Then(@"the trace monitor should capture the logged event")]
        public void ThenTheTraceMonitorShouldCaptureTheLoggedEvent()
        {
            Console.WriteLine("This is picked up in other steps");
        }

        [Then(@"the trace monitor should log event details to msmq")]
        public void ThenTheTraceMonitorShouldLogEventDetailsToMsmq()
        {
            Console.WriteLine("This is picked up in other steps");
        }

        [When(@"execute some code which logs via the CAT team logging framework")]
        public void WhenExecuteSomeCodeWhichLogsViaTheCATTeamLoggingFramework()
        {
            Microsoft.BizTalk.CAT.BestPractices.Framework.Instrumentation.TraceManager.CustomComponent.TraceInfo(
                "This is a test cat team event");


            Microsoft.BizTalk.CAT.BestPractices.Framework.Instrumentation.TraceManager.WorkflowComponent.TraceIn();


            Microsoft.BizTalk.CAT.BestPractices.Framework.Instrumentation.TraceManager.ServiceComponent.TraceIn();
        }
    }
}
